/**
 * List that allows assigning a numerical value called "stage" to every element and accessing them according to the numerical order of the stages (or, if the stages match for multiple values, according to insertion order).
 */
export declare class StagedArray<D> {
    /** Contains tuples used for sorting the data. */
    private stagedData;
    /** Contains the ordered data based on `stagedData`. */
    private orderedStagedData;
    /** Returns a fresh copy of the ordered data array. */
    get orderedData(): D[];
    /** Current length of the array. */
    get length(): number;
    /**
     * Insert new data into this array at the appropriate index.
     *
     * @param stage Stage to use for the given data
     * @param data Data to insert into this array. The order will be preserved.
     */
    addData(stage: number, ...data: D[]): void;
    /**
     * Returns an array containing ordered data from this and the provided SortedArray instances.
     *
     * Ordering is done first by stage, then by order of arguments (with this instance being first).
     *
     * @param stagedArrays Other sorted array instances to take data from
     */
    sortWith(stagedArrays: StagedArray<D>[]): D[];
    /** See `StagedArray.sortWith`. */
    static sort<D>(stagedArrays: StagedArray<D>[]): D[];
}
